# 接入 Matrix

> [!TIP]
> 该平台适配器由社区([stevessr](https://github.com/stevessr)) 维护。如果您觉得有帮助，请支持开发者，给该仓库点一个 Star。❤️

## 安装 astrbot_plugin_matrix_adapter 插件

进入 AstrBot WebUI 的插件市场，搜索 `astrbot_plugin_matrix_adapter`，点击安装。

安装完成后，前往 机器人（旧版本为 `消息平台`） → 新增适配器 → 选择 Matrix（若选项缺失，尝试重启 AstrBot 或检查插件安装状态）。

在弹出的配置对话框中点击 `启用`。

## 配置

请参考该仓库的 [README.md](https://github.com/stevessr/astrbot_plugin_matrix_adapter?tab=readme-ov-file#astrbot-matrix-adapter-%E6%8F%92%E4%BB%B6) 进行配置。

## 问题提交

如有疑问，请提交 issue 至[插件仓库](https://github.com/stevessr/astrbot_plugin_matrix_adapter/issues)。
